# Loom, a plugin for bzr to assist in developing focused patches.
# Copyright (C) 2006 Canonical Limited.

"""Loom specific revision-specifiers."""


from bzrlib.revisionspec import SPEC_TYPES, RevisionSpec, RevisionInfo


class RevisionSpecThread(RevisionSpec):
    """The thread: revision specifier.

    When used just as thread:, the next lower thread from the current thread
    is selected.
    """

    prefix = 'thread:'

    def _match_on(self, branch, revs):
        branch.lock_read()
        try:
            state = branch.get_loom_state()
            threads = state.get_threads()
            current_thread = branch.nick
            index = branch._thread_index(threads, current_thread)
            return RevisionInfo(branch, None, threads[index - 1][1])
        finally:
            branch.unlock()


SPEC_TYPES.append(RevisionSpecThread)
